DEFAULT_DATE_FORMAT = "%Y-%m-%d"
DEFAULT_TIME_FORMAT = "%H:%M:%S"
TIMESTAMP_FORMAT = f"{DEFAULT_DATE_FORMAT} {DEFAULT_TIME_FORMAT}"

DMY_DATE_FORMAT = "%d %m %Y"
DEFAULT_DATE_FORMAT_SLASHED = '%Y/%m/%d'
TIMESTAMP_FORMAT_SLASHED = f"{DEFAULT_DATE_FORMAT_SLASHED} {DEFAULT_TIME_FORMAT}"
HUMAN_FORMAT = "%a %d %b %y, %I:%M:%S %p"
DEFAULT_TIMEZONE = 'Asia/Kolkata'
